## Copyright (C) 2022 Nicola Lunardon

## Distributed as part of the supplementary material for the manuscript
## "Empirical bias-reducing adjustments to estimating functions"
##
## Authors: Nicola Lunardon
## Licence: GPL 2 or greater
## NOT A POLISHED PIECE OF PUBLIC-USE SOFTWARE!  Provided "as is".
## NO WARRANTY OF FITNESS FOR ANY PURPOSE!
##
## It is assumed that the user has a Julia and R installation with all
## packages required by the current script and any other script
## included.
##
##
## Code to reporoduce Table 6 of the main text and Tables S1 and S2 of
## the supporting materials document


##Run the following 4 lines to obtain simulation results

####################################################################################
####################################################################################

##Please note that if n_cores>1 the code cannot run on a Windows machine
###as function "simu.func.ols.ar.miss.distr" makes a call to the function "mclapply"
###of package parallel and Windows does not support "mclapply" with mc.cores>1
###If you wish to run the code in parallel on Windows you need to modifiy the function
###"simu.func.ols.ar.miss.distr" in package "OLStsBR" and replace the call to mclapply
###with a suitable function
####################################################################################
####################################################################################

library(OLStsBR)
#results are going to be saved on the current working directory
simu.func.ols.ar.miss.distr(Under.Distr="normal", n_cores=8, base_n=5e1, path=".", all.methods=FALSE)
simu.func.ols.ar.miss.distr(Under.Distr="t", n_cores=8, base_n=5e1, path=".", all.methods=FALSE)
simu.func.ols.ar.miss.distr(Under.Distr="laplace", n_cores=8, base_n=5e1, path=".", all.methods=FALSE)



##Here we show how to obtain the table displayed in the main text
###(to be run on the directory containing the files saved from the simulation code above)
###the following function just prints the table in latex format
#PLEASE NOTE
#the table reported in Example "Least squares for autoregressive processes"
##is obtained by running the command below and by a little manual editing
##of the table
tables.ar1(theta=0.5)

##By invoking the function "outputs.ar1" we can create some summaries from simulation results
###A brief explanation of the objects returned by the function
####bias: Monte Carlo estimate of bias (multiplied by 100); sample size on columns, estimators on rows
####variance: Monte Carlo estimate of variance; sample size on columns, estimators on rows
####slopes: estimated slopes of the regression lines of the logarithm of the absolute estmated bias
#####as functions of the logarithm of the sample size
####mc_error: simulation error

##example of use
out.normal.05 <- outputs.ar1(Under.Distr="normal", theta=0.5)
out.t.05 <- outputs.ar1(Under.Distr="t", theta=0.5)
out.laplace.05 <- outputs.ar1(Under.Distr="laplace", theta=0.5)

##estimated slopes can be gathered as follows
out.normal.05$slopes
out.t.05$slopes
out.laplace.05$slopes

##The range of the Monte Carlo standard error can be gathered as follows
range(as.numeric(c(out.normal.05$mc_error,out.t.05$mc_error,out.laplace.05$mc_error)))



#Tables in Supporting Material
##Setting theta=0.2
tables.ar1(theta=0.2)
##Setting theta=0.9
tables.ar1(theta=0.9)

##Estimated slopes and Monte Carlo standard error can be gathered as shown above
