## Copyright (C) 2022 Ioannis Kosmidis

## Distributed as part of the supplementary material for the manuscript
## "Empirical bias-reducing adjustments to estimating functions"
##
## Authors: Ioannis Kosmidis
## Licence: GPL 2 or greater
## NOT A POLISHED PIECE OF PUBLIC-USE SOFTWARE!  Provided "as is".
## NO WARRANTY OF FITNESS FOR ANY PURPOSE!
##
## It is assumed that the user has a Julia and R installation with all
## packages required by the current script and any other script
## included.
##
##
## Code for reproducing Table 4 of the main text



using Random, Autologistic, StatsBase, Optim, RCall

## For reproducing the results for Subset 1 run the script by settting subset_to_use = 1.
## For reproducing the results for Subset 2 run the script by settting subset_to_use = 2.
subset_to_use = 1

if subset_to_use == 1
    global area_to_use = 3
    global min_village = 26
    global max_village = 36
end

if subset_to_use == 2
    global area_to_use = 1
    global min_village = 2
    global max_village = 14
end


include("gambia_prepare_data.jl")

seed = 20220502
Random.seed!(seed);

R = 500

## Configure the optimizer
optim_options = Optim.Options(x_tol = 1e-12,
                              f_tol = 1e-12,
                              iterations = 1000,
                              allow_f_increases = true);

## M estimation
res_m = auto_symmetric.fit(zeros(pall), gambia_data, false,
                          optim_options = optim_options, auto_diff = true);

## RBM+ estimation
res_rbmp = auto_symmetric.fit(zeros(pall), gambia_data, true, subsets = subsets, plugin = true,
                              optim_options = optim_options, auto_diff = true);

## Estimates
estimates_m = res_m.minimizer
estimates_rbmp = res_rbmp.minimizer


boot_m = auto_symmetric.boot(
    estimates_m,
    gambia_data,
    false,
    R,
    subsets = subsets,
    plugin = false,
    verbose = 10000,
    Mstart = false,
    optim_options = optim_options)

boot_rbmp = auto_symmetric.boot(
    estimates_rbmp,
    gambia_data,
    true,
    R,
    subsets = subsets,
    plugin = true,
    verbose = 10000,
    Mstart = false,
    optim_options = optim_options)

sum_m = auto_symmetric.summarize_boot(boot_m, C = Inf)
sum_rbmp = auto_symmetric.summarize_boot(boot_rbmp, C = Inf)

inf_m = sum.(eachcol(boot_m["is_infinite"]))
inf_rbmp = sum.(eachcol(boot_rbmp["is_infinite"]))


@rput sum_m sum_rbmp estimates_m estimates_rbmp parnames inf_m inf_rbmp

R"""
library("memisc")
results <- data.frame(parnames, estimates_m, estimates_rbmp, sum_m$ci_norm, sum_rbmp$ci_norm, sum_m$ci_perc, sum_rbmp$ci_perc)
names(results) <- c("parameters", "est-l", "est-lb", "ci-n-l", "ci-n-l", "ci-n-rb", "ci-n-rb",
                                                     "ci-p-l", "ci-p-l", "ci-p-rb", "ci-p-rb")
toLatex(results, digits = 2, useDcolumn = FALSE)
"""


